from setuptools import setup

setup(
    name="black-junit",
    version="0.1.0",
    description="Tool for generation JUnit report from black/blue output",
    url="https://github.com/quantum-0/black-junit",
    author="Anton Kurenkov (Quantum0)",
    author_email="quantum0@mail.ru",
    # license='BSD 2-clause',
    packages=["black_junit"],
    install_requires=["junit_xml"],
    # classifiers=[
    #     'Development Status :: 1 - Planning',
    #     'Intended Audience :: Science/Research',
    #     'License :: OSI Approved :: BSD License',
    #     'Operating System :: POSIX :: Linux',
    #     'Programming Language :: Python :: 2',
    #     'Programming Language :: Python :: 2.7',
    #     'Programming Language :: Python :: 3',
    #     'Programming Language :: Python :: 3.4',
    #     'Programming Language :: Python :: 3.5',
    # ],
)
